<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Parole e Gruppi di parole',
	'mots_slogan' => 'Gestione delle parole e dei gruppi di parole di SPIP',
];
